@@ -3,7 +3,6 @@ import json
 from pagador.acesso.externo import FormatoDeEnvio
 from pagador.envio.requisicao import Enviar
 from pagador.envio.serializacao import Atributo
-from pagador.retorno.models import SituacaoPedido
 from pagador.settings import MERCADOPAGO_PREFERENCE_NOTIFICATION_URL, MEDIA_URL
 
 from pagador_mercadopago.extensao.envio import Preferencia, Payer, BackUrls, Shipments, Item, Phone, Identification, PayerAddress, ReceiverAddress
@@ -101,7 +100,7 @@ class EnviarPedido(Enviar):
         return items
 
     def obter_situacao_do_pedido(self, status_requisicao):
-        return SituacaoPedido.SITUACAO_AGUARDANDO_PAGTO
+        return None
 
     def processar_resposta(self, resposta):
         retorno = json.loads(resposta.content)
